@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 class AdjustedSpan(object):
     def __init__(self, start, stop):
@@ -15,4 +15,4 @@ class AdjustedSpan(object):
         return self.start == other.start and self.stop == other.stop
 
     def __repr__(self):
-        return "<{}({}, {})>".format(self.__class__.__name__, self.start, self.stop)
+        return f"<{self.__class__.__name__}({self.start}, {self.stop})>"
