@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import re
 
-from contrast.extern.six import iteritems, string_types
-
 from contrast.agent.assess.contrast_event import ContrastEvent
 from contrast.agent.assess.properties import Properties
 from contrast.agent.assess.utils import get_properties
@@ -25,14 +23,10 @@ def cs__apply_trigger(
 
     if not node.dataflow_rule:
         if node.good_value:
-            if not isinstance(source, string_types) or re.match(
-                node.good_value, source
-            ):
+            if not isinstance(source, str) or re.match(node.good_value, source):
                 return
         elif node.bad_value:
-            if not isinstance(source, string_types) or not re.match(
-                node.bad_value, source
-            ):
+            if not isinstance(source, str) or not re.match(node.bad_value, source):
                 return
 
         build_finding(
@@ -47,7 +41,7 @@ def cs__apply_trigger(
         )
 
     elif isinstance(source, dict):
-        for key, value in iteritems(source):
+        for key, value in source.items():
             cs__apply_trigger(
                 context, rule, node, key, self_obj, ret, None, args, kwargs
             )
@@ -109,7 +103,7 @@ def build_finding(
 
         target_props = target_properties.properties
         if target_props:
-            for key, value in iteritems(target_props):
+            for key, value in target_props.items():
                 properties[key] = value
 
     parent_ids = (
