@@ -18,12 +18,10 @@ def build_assess_async_method(original_method, patch_policy):
 
     async def assess_method(*args, **kwargs):
         context = contrast.CS__CONTEXT_TRACKER.current()
+        result = None
 
         try:
             result = await original_method(*args, **kwargs)
-        except Exception:
-            result = None
-            raise
         finally:
             analyze(context, patch_policy, result, args, kwargs)
 
