@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.policy import constants
 from contrast.agent.policy.policy_node import PolicyNode
@@ -15,7 +15,7 @@ class DeadZoneNode(PolicyNode):
         config_option=None,
         policy_patch=True,
     ):
-        super(DeadZoneNode, self).__init__(
+        super().__init__(
             module=module,
             class_name=class_name,
             method_name=method_name,
