@@ -26,7 +26,7 @@ from contrast.agent.assess.utils import (
 )
 from contrast.utils.assess.duck_utils import safe_getattr
 from contrast.utils.decorators import log_time
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 
 from contrast.extern import structlog as logging
 
@@ -75,7 +75,7 @@ STREAM_WRITE_METHODS = ["write", "writelines"]
 
 def create_stream_event(node_type, stream, args, kwargs):
     context = contrast.CS__CONTEXT_TRACKER.current()
-    if context is None or not SettingsState().is_assess_enabled():
+    if context is None or not Settings().is_assess_enabled():
         return None
 
     module = stream.__class__.__module__
