@@ -6,7 +6,7 @@ from contrast.agent.assess.policy.source_policy import get_parent_ids
 from contrast.agent.assess.tag import Tag
 from contrast.utils.assess import tracking_util
 from contrast.utils.assess.tag_utils import combine, is_covered
-from contrast.utils.decorators import cached_property, fail_safely
+from contrast.utils.decorators import cached_property, fail_quietly
 from contrast.agent.assess.utils import (
     is_tracked,
     get_properties,
@@ -188,7 +188,7 @@ class BasePropagator(object):
         """
         pass
 
-    @fail_safely("Error during propagation")
+    @fail_quietly("Error during propagation")
     def track_and_propagate(self, ret):
         self.track_target()
         self.propagate()
