@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from .splat_propagator import SplatPropagator
 
@@ -9,5 +9,5 @@ class CodecsSplatPropagator(SplatPropagator):
         """
         Most codecs methods return a tuple where the target string is the first element
         """
-        super(CodecsSplatPropagator, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.target = self.target[0]
