@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern import six
 
 from contrast.agent.assess.utils import copy_from
 from contrast.agent.assess.policy.propagators.base_propagator import BasePropagator
+from contrast.utils.string_utils import ensure_string
 
 
 class ReprPropagator(BasePropagator):
@@ -19,9 +19,9 @@ class ReprPropagator(BasePropagator):
     def _propagate(self):
         # Get a stringy version of the source
         if isinstance(self.first_source, bytearray):
-            string = six.ensure_str(bytes(self.first_source), errors="ignore")
+            string = ensure_string(bytes(self.first_source), errors="ignore")
         else:
-            string = six.ensure_str(self.first_source, errors="ignore")
+            string = ensure_string(self.first_source, errors="ignore")
 
         # See whether the stringy version is inside the repr
         offset = self.target.find(string)
