@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern.six import ensure_binary, iteritems
-
 from contrast.agent.assess.policy.propagators.base_propagator import (
     BasePropagator,
     SUPPORTED_TYPES,
@@ -16,6 +14,8 @@ from contrast.agent.assess.utils import (
 from contrast.utils.assess.duck_utils import is_iterable, safe_iterator
 from contrast.utils.decorators import fail_safely
 
+from contrast.utils.string_utils import ensure_binary
+
 
 class SplatPropagator(BasePropagator):
     """
@@ -86,7 +86,7 @@ class SplatPropagator(BasePropagator):
             if isinstance(source, SUPPORTED_TYPES):
                 _append_if_tracked(source)
             elif isinstance(source, dict):
-                for key, value in iteritems(source):
+                for key, value in source.items():
                     _append_if_tracked(key)
                     _append_if_tracked(value)
             elif is_iterable(source):
