@@ -78,6 +78,19 @@ def apply(
 
         source_type = node.type
         if isinstance(target, FileStorage_types):
+            # first, track the filename, if present
+            filename = getattr(target, "filename", None)
+            cs__apply_source(
+                context,
+                node,
+                filename,
+                target,
+                filename,
+                (),
+                {},
+                source_type="PARAMETER",
+                source_name="filename",
+            )
             # We don't try to propagate through werkzeug's file parsing logic, because
             # it causes massive slowdown. Instead, if we see a FileStorage object
             # come out of a multidict, we track it. We need to track the underlying
