@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import re
-from contrast.extern.six import string_types
 from contrast.agent.assess.policy.trigger_actions.default_action import DefaultAction
 from contrast.utils.decorators import fail_quietly
 
@@ -36,7 +35,7 @@ class RedosAction(DefaultAction):
         self, source_properties, required_tags, disallowed_tags, orig_args=None
     ):
         # 1) Check that user input is untrusted.
-        violated = super(RedosAction, self).is_violated(
+        violated = super().is_violated(
             source_properties, required_tags, disallowed_tags
         )
         if not violated:
@@ -57,7 +56,7 @@ class RedosAction(DefaultAction):
             regex = regex.pattern
 
         redos_regex = (
-            REDOS_REGEX_STRING if isinstance(regex, string_types) else REDOS_REGEX_BYTES
+            REDOS_REGEX_STRING if isinstance(regex, str) else REDOS_REGEX_BYTES
         )
 
         # Even though Ruby uses `match`, we have to use `search` which checks for
