@@ -1,17 +1,13 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import re
-from contrast.extern import six
 
 from contrast.agent.assess.policy.trigger_actions.default_action import DefaultAction
 from contrast.agent.assess.tag import Tag
 from contrast.utils.assess.tag_utils import intersection
 
-if six.PY2:
-    from urllib2 import Request
-else:
-    from urllib.request import Request
+from urllib.request import Request
 
 
 class SsrfAction(DefaultAction):
@@ -34,15 +30,11 @@ class SsrfAction(DefaultAction):
     VULNERABLE_GROUPS = ["protocol", "host"]
 
     def find_all_tag_ranges(self, properties, desired_tags):
-        vulnerable_tag_ranges = super(SsrfAction, self).find_all_tag_ranges(
-            properties, desired_tags
-        )
+        vulnerable_tag_ranges = super().find_all_tag_ranges(properties, desired_tags)
         return self.trim_tag_ranges(properties.origin, vulnerable_tag_ranges)
 
     def find_any_tag_ranges(self, properties, desired_tags):
-        vulnerable_tag_ranges = super(SsrfAction, self).find_any_tag_ranges(
-            properties, desired_tags
-        )
+        vulnerable_tag_ranges = super().find_any_tag_ranges(properties, desired_tags)
         return self.trim_tag_ranges(properties.origin, vulnerable_tag_ranges)
 
     def trim_tag_ranges(self, source, tag_ranges):
@@ -50,7 +42,7 @@ class SsrfAction(DefaultAction):
         Reduce the span of all vulnerable tags to only cover regions of the source URL
         that are actually vulnerable to SSRF.
         """
-        if not isinstance(source, six.string_types):
+        if not isinstance(source, str):
             return tag_ranges
 
         match = re.match(self.SSRF_REGEX, source, flags=re.IGNORECASE)
@@ -68,9 +60,8 @@ class SsrfAction(DefaultAction):
 
     def extract_source(self, source):
         """
-        In py27, urllib2 provides the url via the Request object's get_full_url() method
         In py37, urllib.request does the same, via full_url()
         """
         if isinstance(source, Request):
-            return source.get_full_url() if six.PY2 else source.full_url
+            return source.full_url
         return source
