@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.agent.assess.rules.static_rule import StaticRule
 
 
@@ -14,7 +14,7 @@ class BaseConfigRule(StaticRule):
         return NotImplementedError
 
     def create_properties(self, value, config_path):
-        settings = SettingsState()
+        settings = Settings()
 
         properties = {}
         properties[self.SESSION_ID] = settings.config.get_session_id()
