@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.rules.config.base_config_rule import BaseConfigRule
 from contrast.utils.decorators import fail_safely
@@ -22,8 +22,8 @@ class BaseDjangoConfigRule(BaseConfigRule):
         but that seems like overkill right now.
         """
         if value is None:
-            return "[{} not defined]".format(self.SETTINGS_VALUE)
-        return "{} = {!r}".format(self.SETTINGS_VALUE, value)
+            return f"[{self.SETTINGS_VALUE} not defined]"
+        return f"{self.SETTINGS_VALUE} = {value!r}"
 
     def get_config_value(self, settings):
         return getattr(settings, self.SETTINGS_VALUE, None)
