@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import re
 
-from contrast.extern.six import binary_type, string_types, text_type
-
 from contrast.agent.assess.rules.providers.hardcoded_value_rule import (
     HardcodedValueRule,
 )
@@ -61,7 +59,7 @@ class HardcodedPassword(HardcodedValueRule):
         return not self.probably_property_name(value)
 
     def is_value_type_valid(self, value):
-        return isinstance(value, (binary_type, string_types, text_type, bytearray))
+        return isinstance(value, (bytes, str, bytearray))
 
     # If a field name matches an expected password field, we'll check it's
     # value to see if it looks like a placeholder. For our purposes,
