@@ -6,7 +6,7 @@ import sys
 from inspect import ismethoddescriptor, ismodule
 
 from contrast.agent.assess.rules.static_rule import StaticRule
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.utils.decorators import fail_safely
 from contrast.utils.stdlib_modules import is_stdlib_module
 from .code_parser_mixin import CodeParserMixin
@@ -32,7 +32,7 @@ class HardcodedValueRule(StaticRule, CodeParserMixin):
         return "hardcoded-value-rule"
 
     def applies_to(self, _):
-        settings = SettingsState()
+        settings = Settings()
 
         return settings.is_assess_enabled() and not self.disabled
 
