@@ -1,12 +1,10 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from collections import OrderedDict
 import time
 from weakref import WeakValueDictionary
 
-from contrast.extern.six import PY2, binary_type, string_types, text_type
-
 from contrast.agent import scope
 from contrast.assess_extensions import cs_str
 from contrast.utils.decorators import fail_quietly
@@ -21,11 +19,11 @@ class StringTracker(OrderedDict):
     AGE_OFF_THRESHOLD_SECS = 30
 
     def __init__(self, *args, **kwargs):
-        super(StringTracker, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.pointer_to_props_map = WeakValueDictionary()
 
     def track(self, value):
-        if not isinstance(value, (string_types, text_type, binary_type, bytearray)):
+        if not isinstance(value, (str, bytes, bytearray)):
             return None
 
         # ignore probable interned strings
@@ -38,8 +36,6 @@ class StringTracker(OrderedDict):
             props = Properties(value)
             self.log_tracked(value)
             self[value] = props
-            if PY2:
-                self.update_pointer_map(value, props)
 
         return self[value]
 
@@ -77,24 +73,24 @@ class StringTracker(OrderedDict):
         self[value] = properties
 
     def __delitem__(self, key):
-        return super(StringTracker, self).__delitem__(id(key))
+        return super().__delitem__(id(key))
 
     def __getitem__(self, key):
-        return super(StringTracker, self).__getitem__(id(key))
+        return super().__getitem__(id(key))
 
     def __setitem__(self, key, value):
         if key in self:
             return super(OrderedDict, self).__setitem__(id(key), value)
-        return super(StringTracker, self).__setitem__(id(key), value)
+        return super().__setitem__(id(key), value)
 
     def get(self, key, default=None):
-        return super(StringTracker, self).get(id(key), default)
+        return super().get(id(key), default)
 
     def __contains__(self, key):
-        return super(StringTracker, self).__contains__(id(key))
+        return super().__contains__(id(key))
 
     def get_by_id(self, key_id):
-        return super(StringTracker, self).__getitem__(key_id)
+        return super().__getitem__(key_id)
 
     def values(self):
         "od.values() -> list of values in od"
@@ -119,11 +115,11 @@ class StringTracker(OrderedDict):
         now = time.time()
         # Keys are IDs in this loop
         for key in list(self.keys()):
-            props = super(StringTracker, self).__getitem__(key)
+            props = super().__getitem__(key)
             if (now - props.timestamp) > self.AGE_OFF_THRESHOLD_SECS:
                 self.log_ageoff(props.origin)
                 try:
-                    super(StringTracker, self).__delitem__(key)
+                    super().__delitem__(key)
                 except KeyError:
                     # Handles potential race condition that may occur if
                     # another thread may have already deleted the key after
