@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import contrast
 from contrast.agent.assess.adjusted_span import AdjustedSpan
@@ -82,7 +82,7 @@ def get_self_for_method(patch_policy, args):
 
     If any node in the policy has a False instance_method attribute return None
     """
-    for node in patch_policy.all_nodes():
+    for node in patch_policy.all_nodes:
         if not node.instance_method:
             return None
 
