@@ -53,4 +53,11 @@ class Heartbeat(threading.Thread):
             self.settings.last_update is not None
             and (now_ms() - self.settings.last_update) > heartbeat_interval_ms
         ):
-            service_client.send_heartbeat_message()
+            if self.settings.config.is_service_bypassed:
+                from contrast.reporting import ReportingClient
+                from contrast.reporting.teamserver_messages import HeartBeat
+
+                client = ReportingClient()
+                client.send_message(HeartBeat())
+            else:
+                service_client.send_heartbeat_message()
