@@ -7,11 +7,11 @@ import sys
 
 from contrast import __version__, AGENT_CURR_WORKING_DIR
 from contrast.reporting import teamserver_messages
-from contrast.agent.patch_controller import disable_assess_patches
 from contrast.agent import patch_controller, service_client, scope
+from contrast.agent.request_context import RequestContext
 from contrast.agent.telemetry import telemetry_disabled
-from contrast.agent.policy.loader import Policy
-from contrast.agent.assess.policy import trigger_policy
+from contrast.agent.assess.rules.response.xss import analyze_xss
+from contrast.agent.assess.rules.response.analyze import analyze_response_rules
 from contrast.agent.assess.preflight import update_preflight_hashes
 from contrast.agent.assess.rules.providers.enable import enable_providers
 from contrast.agent.middlewares.route_coverage.routes_mixin import RoutesMixin
@@ -29,6 +29,7 @@ from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.library_reader.library_reader import LibraryReader
 from contrast.utils.loggers.logger import setup_agent_logger, setup_basic_agent_logger
 from contrast.utils.timer import now_ms_float, now_ms
+from contrast.utils.decorators import fail_safely
 from contrast.assess_extensions import cs_str
 
 if not telemetry_disabled():
@@ -95,7 +96,6 @@ class BaseMiddleware(RoutesMixin):
 
         self.settings = None
         self.routes = {}
-        self.first_request = True
 
         if not self.initialize_settings(self.app_name):
             logger.error("Unable to initialize Contrast Agent.")
@@ -149,7 +149,9 @@ class BaseMiddleware(RoutesMixin):
             self.telemetry = Telemetry()
             self.telemetry.start()
 
+        self.first_request = True
         self.request_start_time = None
+        self.request_path = None
         BaseMiddleware._loaded = True
 
     def initialize_settings(self, app_name):
@@ -275,22 +277,39 @@ class BaseMiddleware(RoutesMixin):
     def call_with_agent(self, context, environ, start_response):
         pass
 
-    def call_without_agent(self, path):
+    def call_without_agent(self):
         """
-        If Agent is either disabled or not initialized due to either entire settings
-        initialization failing or just loggers failing, then we should print to stdout
-        that the Agent is not running.
-
-        In the case of the agent is disabled by a reaction from SR, we have to disable
-        assess patches here because checking for context inside of our builtin string
-        patches is much more expensive to do since they are called very frequently.
-
         The agent does not set context when this function is called so all other patches
         (e.g propagators) that check context shouldn't run.
         """
-        disable_assess_patches()
+        logger.debug("Contrast Agent did not analyze request %s", self.request_path)
 
-        logger.warning("Contrast Agent did not analyze request %s", path)
+    def should_analyze_request(self, environ):
+        """
+        Determine if request should be analyzed based on configured settings.
+
+        While returning different types of objects based on logic is not a good
+        pattern, in this case it's an optimization that allows us to create
+        the request context obj when we need it.
+
+        :return: False or RequestContext instance
+        """
+        if not self.is_agent_enabled():
+            logger.debug("Will not analyze request: agent disabled.")
+            return False
+
+        if self.settings.ignore_request(self.request_path):
+            logger.debug("Will not analyze request: request meets exclusions.")
+            return False
+
+        from contrast.agent.assess import sampling
+
+        context = RequestContext(environ)
+        if sampling.enabled() and sampling.meets_criteria(context):
+            logger.debug("Will not analyze request: request meets sampling.")
+            return False
+
+        return context  # equivalent to returning True
 
     def handle_ensure(self, context, request):
         """
@@ -310,19 +329,19 @@ class BaseMiddleware(RoutesMixin):
 
             logger.debug("Sending final messages for reporting.")
 
-            final_messages = self.final_messages(context)
-            service_client.send_messages(final_messages)
-
-            if self.reporting_client:
+            if self.settings.config.is_service_bypassed:
                 for msg in self.final_ts_messages(context):
                     self.reporting_client.add_message(msg)
+            else:
+                final_messages = self.final_messages(context)
+                service_client.send_messages(final_messages)
 
         self.first_request = False
 
     def final_ts_messages(self, context):
         messages = [
             teamserver_messages.ServerActivity(),
-            teamserver_messages.Preflight(context.activity.findings),
+            teamserver_messages.Preflight(context.activity),
         ]
 
         # Currently we do not report an observed route if the route signature is empty.
@@ -428,7 +447,7 @@ class BaseMiddleware(RoutesMixin):
             scope.exit_contrast_scope()
 
     def prefilter_defend(self):
-        rules = self.settings.defend_rules
+        rules = self.settings.protect_rules
         logger.debug("PROTECT: Running Agent prefilter.")
 
         for rule in rules.values():
@@ -452,12 +471,8 @@ class BaseMiddleware(RoutesMixin):
                     logger.exception("PROTECT: threw exception in postfilter")
 
             if self.settings.is_assess_enabled():
-                scope.enter_contrast_scope()
-                try:
-                    self.postfilter_assess(context)
-                except Exception:
-                    logger.exception("ASSESS: threw exception in postfilter")
-                scope.exit_contrast_scope()
+                with scope.contrast_scope():
+                    self.response_analysis(context)
 
     def _process_trigger_handler(self, handler):
         """
@@ -493,70 +508,28 @@ class BaseMiddleware(RoutesMixin):
         """
         raise NotImplementedError("Children must define trigger_node property")
 
-    def assess_reflected_xss_postfilter(self, context):
-        """
-        Evaluate xss rule for assess
-
-        The xss rule is applied to the response body in order to determine whether it
-        contains untrusted data. We rely on propagation through any template rendering
-        and through the framework. The expectation is that untrusted data from
-        a request will propagate successfully all the way to the response body, which
-        we are able to see here.
-
-        Each child middleware class must implement specific logic for the trigger node
-        since the reporting will differ between frameworks.
-        """
-        policy = Policy()
-
-        rule = policy.triggers["reflected-xss"]
-
-        # We need to exit scope here in order to account for the fact that some
-        # frameworks evaluate the content lazily. We don't want to be in scope when
-        # that occurs since it would make us lose propagation. This would prevent us
-        # from seeing the response as a tracked string, which we require in order to
-        # apply the rule.
-        with scope.pop_contrast_scope():
-            result = context.response.body
-
-        trigger_node, args = self.trigger_node
-
-        trigger_policy.apply(rule, [trigger_node], result, args)
-
-    def postfilter_assess(self, context):
+    @fail_safely("Unable to do assess response analysis")
+    def response_analysis(self, context):
         """
         Run postfilter for any assess rules. Reflected xss rule runs by default.
         May be overridden in child classes.
 
         If the response content type matches a allowed content type, do not run
-        xss postfilter assess This is because the security team
+        assess xss response analysis. This is because the security team
         considers reflected xss within these content types to be a false positive.
         """
-        logger.debug("ASSESS: Running Agent postfilter.")
+        logger.debug("ASSESS: Running response analysis")
 
-        # it is possible other forms (capital case) variants exist
-        accepted_xss_response_content_types = [
-            "/csv",
-            "/javascript",
-            "/json",
-            "/pdf",
-            "/x-javascript",
-            "/x-json",
-            "/plain",
-        ]
+        analyze_xss(context, self.trigger_node)
 
-        content_type = context.response.headers.get("content-type", "")
+        if not self.settings.response_scanning_enabled:
+            return
 
-        if not any(
-            [
-                name
-                for name in accepted_xss_response_content_types
-                if name in content_type
-            ]
-        ):
-            self.assess_reflected_xss_postfilter(context)
+        if self.reporting_client:
+            analyze_response_rules(context, self.reporting_client)
 
     def postfilter_defend(self):
-        rules = self.settings.defend_rules
+        rules = self.settings.protect_rules
         logger.debug("PROTECT: Running Agent postfilter.")
 
         for rule in rules.values():
@@ -585,17 +558,17 @@ class BaseMiddleware(RoutesMixin):
                 msg = f"Rule {result.rule_id} threw a security exception"
                 raise SecurityException(None, message=msg)
 
-    def log_start_request_analysis(self, request_path):
+    def log_start_request_analysis(self):
         self.request_start_time = now_ms_float()
 
-        logger.debug("Beginning request analysis", request_path=request_path)
+        logger.debug("Beginning request analysis", request_path=self.request_path)
 
-    def log_end_request_analysis(self, request_path):
+    def log_end_request_analysis(self):
         request_end_time = now_ms_float()
 
         logger.debug(
             "Ending request analysis",
-            request_path=request_path,
+            request_path=self.request_path,
         )
 
         elapsed_time = request_end_time - self.request_start_time
@@ -603,7 +576,7 @@ class BaseMiddleware(RoutesMixin):
         logger.debug(
             "elapsed time request analysis ms",
             elapsed_time=elapsed_time,
-            request_path=request_path,
+            request_path=self.request_path,
         )
 
     def log_initialize(self):
