@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern.six import iteritems
-
 from contrast.agent import scope
 from contrast.agent.assess.policy.analysis import skip_analysis
 from contrast.agent.assess.policy.source_node import SourceNode
@@ -10,7 +8,6 @@ from contrast.agent.assess.policy.source_policy import cs__apply_source
 from contrast.utils.assess.stream_utils import ContrastWsgiStreamProxy
 from contrast.utils.decorators import fail_safely, log_time
 
-
 # a best effort at translating the types in this document:
 # https://bitbucket.org/contrastsecurity/teamserver/src/
 # 862d499227e8eac42b6eb7c6b03f10b7f1556218/teamserver-agent-messages/src/main/java/
@@ -59,7 +56,7 @@ def track_cookie_sources(framework, context, cookies):
 
 @log_time("tracking environ sources")
 @fail_safely("Failed to track environ sources")
-def track_environ_sources(framework, context, environ, skip_wsgi_input=False):
+def track_environ_sources(framework, context, environ):
     """
     This method will track necessary information in the environ
 
@@ -68,7 +65,6 @@ def track_environ_sources(framework, context, environ, skip_wsgi_input=False):
     :param framework: current application's framework
     :param context: current request context
     :param environ: WSGI environ dict
-    :param skip_wsgi_input: If True, do not track the wsgi.input stream.
 
     :return: None
     """
@@ -76,12 +72,11 @@ def track_environ_sources(framework, context, environ, skip_wsgi_input=False):
         return
 
     with scope.contrast_scope():
-        for key, value in iteritems(environ):
+        for key, value in environ.items():
             _track_environ_item(framework, context, environ, key, value)
 
-        if not skip_wsgi_input:
-            _make_request_body_seekable(context.request)
-            _track_wsgi_input(environ)
+        _make_request_body_seekable(context.request)
+        _track_wsgi_input(environ)
         _remove_webob_environ_vars(environ)
 
 
