@@ -2,8 +2,12 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.api import Route
-from contrast.agent.middlewares.route_coverage.coverage_utils import CoverageUtils
-from contrast.agent.middlewares.route_coverage.common import build_route
+from contrast.agent.middlewares.route_coverage.common import (
+    build_route,
+    get_normalized_uri,
+    build_key,
+)
+
 from aiohttp.web_urldispatcher import DynamicResource
 
 
@@ -30,10 +34,10 @@ def create_aiohttp_routes(app):
                 else app_route._path
             )
             method_type = resource.method
-            key = CoverageUtils.build_key(route_id, method_type)
+            key = build_key(route_id, method_type)
             routes[key] = Route(
                 verb=method_type,
-                url=CoverageUtils.get_normalized_uri(_route_attr),
+                url=get_normalized_uri(_route_attr),
                 route=route,
             )
 
