@@ -2,11 +2,13 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.api import Route
-from contrast.agent.middlewares.route_coverage.coverage_utils import (
-    CoverageUtils,
-    DEFAULT_ROUTE_METHODS,
-)
 from contrast.utils.decorators import fail_safely
+from contrast.agent.middlewares.route_coverage.common import (
+    DEFAULT_ROUTE_METHODS,
+    build_args_from_function,
+    build_key,
+    get_normalized_uri,
+)
 from pyramid.interfaces import IView, IViewClassifier, IRouteRequest, IRoutesMapper
 from zope.interface import Interface
 
@@ -58,9 +60,9 @@ def create_pyramid_routes(registry):
             methods = pyramid_route.predicates or DEFAULT_ROUTE_METHODS
 
             for method_type in methods:
-                key = CoverageUtils.build_key(route_id, method_type)
+                key = build_key(route_id, method_type)
 
-                url = CoverageUtils.get_normalized_uri(pyramid_route.path)
+                url = get_normalized_uri(pyramid_route.path)
                 routes[key] = Route(verb=method_type, url=url, route=route)
         else:
             logger.debug("Unable to add %s to route coverage.", pyramid_route.path)
@@ -69,7 +71,7 @@ def create_pyramid_routes(registry):
 
 
 def build_pyramid_route(pyramid_route_name, view_func):
-    method_arg_names = CoverageUtils.build_args_from_function(view_func)
+    method_arg_names = build_args_from_function(view_func)
 
     return pyramid_route_name + method_arg_names
 
@@ -84,9 +86,8 @@ class PyramidRoutesMixin(object):
         return create_pyramid_routes(self.registry)
 
     @fail_safely("Unable to find new routes")
-    def get_view_func(self, request):
-        path = request.environ.get("PATH_INFO", "")
-        if not path:
+    def get_view_func(self, _):
+        if not self.request_path:
             logger.debug("No path info for pyramid request")
             return None
 
@@ -99,7 +100,7 @@ class PyramidRoutesMixin(object):
         # iterate over all the routes to find it by the path
         # pyramid_route = mapper.get_route(name)
 
-        matching_routes = [x for x in routes if x.path == path]
+        matching_routes = [x for x in routes if x.path == self.request_path]
         if not matching_routes:
             return None
 
