@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.agent.middlewares.route_coverage.coverage_utils import CoverageUtils
 from contrast.api import Finding, Route
 from contrast.utils.decorators import log_time
+from contrast.agent.middlewares.route_coverage.common import build_key
 
 from contrast.extern import structlog as logging
 
@@ -64,7 +64,7 @@ class RoutesMixin(object):
             return
 
         request_method = request.method
-        route_id = CoverageUtils.build_key(str(id(func)), request_method)
+        route_id = build_key(str(id(func)), request_method)
 
         self.update_route_information(context, route_id, request_method, func)
 
