@@ -31,7 +31,7 @@ from contrast.agent.assess.policy.patches import (
     build_assess_property_fget,
     apply_cached_property,
 )
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.agent.assess.policy.source_node import SourceNode
 from contrast.agent.assess.policy.utils import build_method_name
 from contrast.assess_extensions import smart_setattr
@@ -227,7 +227,7 @@ def apply_module_patches(module):
         logger.debug("WARNING: No module policy found for %s", module_name)
         return
 
-    settings = SettingsState()
+    settings = Settings()
 
     for patch_policy in policy.policy_by_module[module_name]:
         if patch_policy.name in PATCH_LOCATIONS:
