@@ -8,7 +8,7 @@ from contrast.agent.assess.policy import propagation_policy
 from contrast.agent.assess.policy import source_policy
 from contrast.agent.assess.policy import trigger_policy
 from contrast.agent.policy.trigger_node import TriggerNode
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.utils.decorators import cached_property
 
 
@@ -95,7 +95,7 @@ class PatchLocationPolicy(object):
         (a) it does not have an associated config option
         (b) its associated config option indicates that the deadzone should be applied
         """
-        settings = SettingsState()
+        settings = Settings()
 
         return any(
             [
