@@ -29,9 +29,6 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
     START_IDX = "start_idx"
     END_IDX = "end_idx"
 
-    def __init__(self, settings):
-        BaseRule.__init__(self, settings)
-
     def find_attack(self, candidate_string=None, **kwargs):
         command_string = str(candidate_string) if candidate_string else None
 
