@@ -13,9 +13,6 @@ class MethodTampering(BaseRule):
     NAME = "method-tampering"
     USER_INPUT_KEY = UserInput.InputType.Name(UserInput.METHOD)
 
-    def __init__(self, settings):
-        BaseRule.__init__(self, settings)
-
     def postfilter(self):
         """
         At postfilter we generate activity if input analysis was found and depending on application response code.
@@ -28,6 +25,11 @@ class MethodTampering(BaseRule):
         evaluations_for_rule = self.evaluations_for_rule()
 
         context = contrast.CS__CONTEXT_TRACKER.current()
+        if context is None or not hasattr(context, "response"):
+            # do not remove; this case is not yet well-understood
+            logger.debug("WARNING: failed to get context in MethodTampering.postfilter")
+            return
+
         response_code = context.response.status_code
 
         for evaluation in evaluations_for_rule:
