@@ -12,9 +12,6 @@ class MalformedHeader(BaseRule):
 
     NAME = "malformed-header"
 
-    def __init__(self, settings):
-        BaseRule.__init__(self, settings)
-
     @property
     def mode(self):
         """
