@@ -17,9 +17,6 @@ SAFE_PATHS = ["tmp", "public", "docs", "static", "template", "templates"]
 class PathTraversal(BaseRule, PathTraversalSinkFeatures):
     NAME = "path-traversal"
 
-    def __init__(self, settings):
-        BaseRule.__init__(self, settings)
-
     def find_attack(self, candidate_string=None, analysis_stage=None, **kwargs):
         """
         Finds the attacker in the original string if present
