@@ -24,9 +24,6 @@ class SqlInjection(BaseRule):
 
     NAME = "sql-injection"
 
-    def __init__(self, settings):
-        BaseRule.__init__(self, settings)
-
     def build_attack_with_match(
         self, candidate_string, evaluation=None, attack=None, **kwargs
     ):
