@@ -16,9 +16,6 @@ class Ssrf(BaseRule):
 
     NAME = "ssrf"
 
-    def __init__(self, settings):
-        BaseRule.__init__(self, settings)
-
     def is_postfilter(self):
         return False
 
