@@ -13,9 +13,6 @@ class Xss(BaseRule):
 
     NAME = "reflected-xss"
 
-    def __init__(self, settings):
-        BaseRule.__init__(self, settings)
-
     @property
     def mode(self):
         """
