@@ -8,7 +8,8 @@ from contrast.agent.settings import Settings
 from contrast.api.dtm_pb2 import Activity, ServerActivity, ObservedRoute
 
 from contrast.extern import structlog as logging
-
+from contrast.utils.digest_utils import Digest
+from contrast.utils.decorators import cached_property, fail_quietly
 from contrast.utils.string_utils import ensure_binary
 
 logger = logging.getLogger("contrast")
@@ -16,9 +17,6 @@ logger = logging.getLogger("contrast")
 
 class RequestContext(object):
     def __init__(self, environ):
-
-        logger.debug("Initializing Request Context")
-
         scope.enter_contrast_scope()
 
         self.request = Request(environ)
@@ -45,6 +43,25 @@ class RequestContext(object):
 
         scope.exit_contrast_scope()
 
+    @cached_property
+    @fail_quietly("Unable to compute request hash")
+    def hash(self):
+        """
+        Generates the hash checksum for the request. Converts the request method, uri,
+        param names and content length to CRC checksum and returns string representation
+
+        :return: str
+        """
+        hasher = Digest()
+
+        hasher.update(self.request.method)
+        hasher.update(self.request.get_normalized_uri())
+        for key in self.request.params:
+            hasher.update(key)
+
+        hasher.update(self.request.content_length)
+        return hasher.finish()
+
     @property
     def stop_source_creation(self):
         """
