@@ -8,7 +8,7 @@ import struct
 import contrast
 from contrast.agent.connection_status import ConnectionStatus
 from contrast.agent.service_config import ServiceConfig
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.api.dtm_pb2 import (
     Activity,
     AgentStartup,
@@ -46,7 +46,7 @@ class _ServiceState(Singleton):
         self.count = 0
         self.connection_status = ConnectionStatus()
         self.bundled_flag = "external"
-        self.service_config = ServiceConfig(SettingsState().config)
+        self.service_config = ServiceConfig(Settings().config)
         self.poll = Poll()
 
     @property
@@ -61,7 +61,7 @@ class _ServiceState(Singleton):
         client_id must be the parent process id as it is the same for all workers serving an app.
         :return: str app name and parent process id
         """
-        return str(SettingsState().app_name) + "-" + str(os.getppid())
+        return str(Settings().app_name) + "-" + str(os.getppid())
 
     @property
     def app_path(self):
@@ -70,8 +70,7 @@ class _ServiceState(Singleton):
         in common config or by looking at the current working dir.
         """
         return (
-            SettingsState().config.get("application.path")
-            or contrast.AGENT_CURR_WORKING_DIR
+            Settings().config.get("application.path") or contrast.AGENT_CURR_WORKING_DIR
         )
 
     @property
@@ -86,7 +85,7 @@ class _ServiceState(Singleton):
 
         :return: bool if bundled Contrast Service was started.
         """
-        settings = SettingsState()
+        settings = Settings()
 
         logger.info(
             "Attempted to start bundled Contrast Service for application %s.",
@@ -120,7 +119,7 @@ class _ServiceState(Singleton):
         :return: list of Message responses
 
         """
-        settings = SettingsState()
+        settings = Settings()
 
         if settings.is_bundled_enabled and self.local_service_configured:
             self.bundled_flag = "bundled"
@@ -135,7 +134,7 @@ class _ServiceState(Singleton):
         self._build_and_send_startup_msgs()
 
     def _build_and_send_startup_msgs(self):
-        settings = SettingsState()
+        settings = Settings()
 
         first_msg = self._build_agent_startup_msg(settings)
 
@@ -325,7 +324,7 @@ class _ServiceState(Singleton):
         return bytes(buffer_array)
 
     def build_empty_message(self):
-        settings = SettingsState()
+        settings = Settings()
 
         message = Message()
         message.app_name = settings.app_name
@@ -407,7 +406,7 @@ class _ServiceState(Singleton):
 
         agent_startup.version = contrast.__version__
 
-        settings = SettingsState()
+        settings = Settings()
 
         log_info = {
             "Server Name": agent_startup.server_name,
@@ -449,13 +448,10 @@ def build_update_message(routes):
     """
     Create an ApplicationUpdate message with framework information and routes.
 
-    :param routes: Dict of RouteCoverage, will be empty if in Protect mode
+    :param routes: Dict of api.Route, will be empty if in Protect mode
     :return: ApplicationUpdate instance
     """
-    settings = SettingsState()
-
-    if not settings.is_inventory_enabled():
-        return None
+    settings = Settings()
 
     update_message = ApplicationUpdate()
 
@@ -466,7 +462,7 @@ def build_update_message(routes):
     # Route coverage is an assess feature. Routes will be empty
     # so the update_message will have no routes.
     for route in routes.values():
-        update_message.routes.extend([route])
+        update_message.routes.extend([route.to_dtm()])
 
     return update_message
 
@@ -491,7 +487,7 @@ def send_messages(messages):
     :side effect: ContrastServiceException could be raised but should be catch by the middleware
     """
     responses = send_messages_get_responses(messages)
-    SettingsState().process_responses(responses)
+    Settings().process_responses(responses)
 
 
 def send_heartbeat_message():
