@@ -8,7 +8,6 @@ from aiohttp.web import Response, StreamResponse
 from aiohttp.web_urldispatcher import DynamicResource
 
 from contrast.aiohttp import sources
-from contrast.agent.request_context import RequestContext
 from contrast.agent import scope
 from contrast.agent.middlewares.route_coverage.aiohttp_routes import (
     create_aiohttp_routes,
@@ -45,31 +44,21 @@ class AioHttpMiddleware(BaseMiddleware):
     async def __call__(self, request, handler) -> StreamResponse:
         self.app = request.app
 
-        path = sources.get_path_query(request.message)
+        self.request_path = sources.get_path_query(request.message)[0]
 
-        with Profiler(path[0]):
-            if self.is_agent_enabled():
-                if self.settings.ignore_request(path[0]):
-                    return await self.call_without_agent_async(
-                        request, handler, path[0]
-                    )
-
-                with scope.contrast_scope():
-                    environ = await sources.aiohttp_request_to_environ(request)
-
-                context = RequestContext(environ)
+        with Profiler(self.request_path):
+            with scope.contrast_scope():
+                environ = await sources.aiohttp_request_to_environ(request)
 
+            context = self.should_analyze_request(environ)
+            if context:
                 with contrast.CS__CONTEXT_TRACKER.lifespan(context):
-                    return await self.call_with_agent(
-                        context, request, handler, path[0]
-                    )
+                    return await self.call_with_agent(context, request, handler)
 
-            return await self.call_without_agent_async(request, handler, path[0])
+            return await self.call_without_agent_async(request, handler)
 
-    async def call_with_agent(
-        self, context, request, handler, path: str
-    ) -> StreamResponse:
-        self.log_start_request_analysis(path[0])
+    async def call_with_agent(self, context, request, handler) -> StreamResponse:
+        self.log_start_request_analysis()
 
         sources.track_aiohttp_request_sources(context, request)
 
@@ -92,18 +81,18 @@ class AioHttpMiddleware(BaseMiddleware):
         except ContrastServiceException as e:
             # handle_ensure should not be called here
             logger.warning(e)
-            return await self.call_without_agent_async(request, handler, path)
+            return await self.call_without_agent_async(request, handler)
         except Exception as e:
             self.handle_ensure(context, request)
             response = self.handle_exception(e)
             return response
         finally:
-            self.log_end_request_analysis(path[0])
+            self.log_end_request_analysis()
             if self.settings.is_assess_enabled():
                 contrast.STRING_TRACKER.ageoff()
 
-    async def call_without_agent_async(self, request, handler, path) -> StreamResponse:
-        super().call_without_agent(path)
+    async def call_without_agent_async(self, request, handler) -> StreamResponse:
+        super().call_without_agent()
         return await handler(request)
 
     @fail_safely("Unable to get route coverage", return_value={})
@@ -116,7 +105,9 @@ class AioHttpMiddleware(BaseMiddleware):
 
     @fail_safely("Unable to get view func")
     def get_view_func(self, request):
-        path = sources.get_path_query(request.message)
+        if not self.request_path:
+            return None
+
         view_func = None
 
         # This approach has at worst O(_resources) performance
@@ -128,7 +119,7 @@ class AioHttpMiddleware(BaseMiddleware):
                 if isinstance(app_route, DynamicResource)
                 else app_route._path
             )
-            if _app_route == path[0]:
+            if _app_route == self.request_path:
                 routes = app_route._routes
                 for route in routes:
                     if route.method == request.method:
