@@ -64,15 +64,13 @@ def apply_rule(adapter_name, orig_func, args, kwargs):
     @return: Returns the object that is returned by calling orig_func
     """
     context = contrast.CS__CONTEXT_TRACKER.current()
+    result = None
 
     if context is not None:
         _protect_rule(context, adapter_name, orig_func.__name__, args, kwargs)
 
     try:
         result = orig_func(*args, **kwargs)
-    except Exception:
-        result = None
-        raise
     finally:
         if not skip_analysis(context):
             assess_rule(context, adapter_name, orig_func.__name__, result, args, kwargs)
@@ -98,5 +96,5 @@ def _protect_rule(context, adapter_name, method, args, kwargs):
     trigger_node = TriggerNode(adapter_name, "unused", True, method, "ARG_0")
     patch_policy = PatchLocationPolicy(trigger_node)
 
-    rule = Settings().defend_rules.get(SqlInjection.NAME)
+    rule = Settings().protect_rules.get(SqlInjection.NAME)
     rule.protect(patch_policy, sql, args, kwargs)
