@@ -1,5 +1,5 @@
 /*
- * Copyright © 2021 Contrast Security, Inc.
+ * Copyright © 2022 Contrast Security, Inc.
  * See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
  */
 /* Python requires its own header to always be included first */
@@ -8,7 +8,6 @@
 
 #include <contrast/assess/patches.h>
 #include <contrast/assess/scope.h>
-#include <contrast/assess/threadlocal_storage.h>
 
 static PyMethodDef methods[] = {
     {"initialize",
@@ -36,7 +35,7 @@ static PyMethodDef methods[] = {
     {"set_exact_scope",
      set_exact_scope,
      METH_O,
-     "Sets the scope in the thread exactly what you pass to it"},
+     "Sets the scope exactly what you pass to it"},
     {"enter_scope", enter_scope, METH_VARARGS, "Enter given scope"},
     {"exit_scope", exit_scope, METH_VARARGS, "Exit given scope"},
     {"in_scope", in_scope, METH_VARARGS, "Check whether in given scope"},
@@ -44,8 +43,6 @@ static PyMethodDef methods[] = {
      in_contrast_or_propagation_scope,
      METH_NOARGS,
      "Check in propagation (or contrast) scope"},
-
-#ifdef USE_CONTEXTVARS
     {"get_current_scope",
      get_current_scope,
      METH_NOARGS,
@@ -54,19 +51,6 @@ static PyMethodDef methods[] = {
      init_contrast_scope_cvars,
      METH_NOARGS,
      "Initialize ContextVars used for scope"},
-#else
-    /* TODO: PYT-1745 create_thread_storage will need different flags */
-    {"create_thread_storage",
-     create_thread_storage,
-     METH_O,
-     "Create thread storage with initial scope and context"},
-    {"destroy_thread_storage",
-     destroy_thread_storage,
-     METH_NOARGS,
-     "Teardown storage for thread"},
-    {"get_thread_scope", get_thread_scope, METH_NOARGS, "Get scope level for thread"},
-#endif
-
     {"set_attr_on_type", set_attr_on_type, METH_VARARGS, "Set attribute on type"},
     {NULL, NULL, 0, NULL}};
 
@@ -88,16 +72,9 @@ PyMODINIT_FUNC PyInit_cs_str(void) {
 
     module = PyModule_Create(&cs_str_definition);
 
-#ifdef USE_CONTEXTVARS
-    PyModule_AddIntConstant(module, "USE_CONTEXTVARS", 1);
-#else
-    PyModule_AddIntConstant(module, "USE_CONTEXTVARS", 0);
-#endif
-
     PyModule_AddIntConstant(module, "CONTRAST_SCOPE", CONTRAST_SCOPE);
     PyModule_AddIntConstant(module, "PROPAGATION_SCOPE", PROPAGATION_SCOPE);
     PyModule_AddIntConstant(module, "TRIGGER_SCOPE", TRIGGER_SCOPE);
-    PyModule_AddIntConstant(module, "EVAL_SCOPE", EVAL_SCOPE);
 
     return module;
 }
