@@ -5,10 +5,8 @@ from contrast.wsgi.middleware import WSGIMiddleware
 from contrast.agent.middlewares.app_finder import get_original_app_or_fail
 from contrast.utils.decorators import fail_safely, fail_quietly
 from contrast.extern import structlog as logging
-from contrast.agent.middlewares.route_coverage.bottle_routes import (
-    create_bottle_routes,
-    build_bottle_route,
-)
+from contrast.agent.middlewares.route_coverage.bottle_routes import create_bottle_routes
+from contrast.agent.middlewares.route_coverage.common import build_route
 import bottle
 
 logger = logging.getLogger("contrast")
@@ -44,4 +42,4 @@ class BottleMiddleware(WSGIMiddleware):
 
     @fail_safely("Unable to build route", return_value="")
     def build_route(self, view_func, url):
-        return build_bottle_route(url, view_func)
+        return build_route(url, view_func)
