@@ -422,9 +422,15 @@ class Assess(ConfigBuilder):
                 default_value=True,
                 type_cast=utils.str_to_bool,
             ),
+            ConfigOption(
+                name="sampling.enable", default_value=False, type_cast=utils.str_to_bool
+            ),
             ConfigOption(name="sampling.baseline", default_value=5, type_cast=int),
             ConfigOption(
-                name="sampling.enable", default_value=True, type_cast=utils.str_to_bool
+                name="sampling.request_frequency", default_value=10, type_cast=int
+            ),
+            ConfigOption(
+                name="sampling.window_ms", default_value=180_000, type_cast=int
             ),
             ConfigOption(name="tags", default_value="", type_cast=str),
             ConfigOption(
@@ -487,7 +493,7 @@ class Protect(ConfigBuilder):
 
         self.default_options = [
             ConfigOption(
-                name="enable", default_value=True, type_cast=utils.str_to_bool
+                name="enable", default_value=None, type_cast=utils.str_to_bool
             ),
             ConfigOption(name="samples.probed", default_value=50, type_cast=int),
             ConfigOption(name="samples.blocked", default_value=25, type_cast=int),
