@@ -22,7 +22,6 @@ try:
 except ImportError:
     from django.core.urlresolvers import get_resolver
 
-
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
@@ -60,8 +59,17 @@ class DjangoWSGIMiddleware(WSGIMiddleware):
 
     @fail_safely("Unable to get Django view func")
     def get_view_func(self, request):
-        match = get_resolver().resolve(request.path_info or "/")
-        if not match:
+        from django.conf import settings
+
+        match = self._run_router(self.request_path)
+        if (
+            match is None
+            and not self.request_path.endswith("/")
+            and "django.middleware.common.CommonMiddleware" in settings.MIDDLEWARE
+            and settings.APPEND_SLASH
+        ):
+            match = self._run_router(f"{self.request_path}/")
+        if match is None:
             return None
 
         return match.func
@@ -99,3 +107,9 @@ class DjangoWSGIMiddleware(WSGIMiddleware):
 
         for rule in self.config_rules:
             rule.apply(app_settings, app_config_module)
+
+    def _run_router(self, path):
+        try:
+            return get_resolver().resolve(path or "/")
+        except Exception:
+            return None
