@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import sys
 
@@ -49,7 +49,7 @@ def dialect_init_wrapper(wrapped, instance, args, kwargs):
     See https://wrapt.readthedocs.io/en/latest/wrappers.html#function-wrappers.
     """
     if "dbapi" in kwargs:
-        dbapi2.instrument_adapter("sqlalchemy", kwargs["dbapi"])
+        dbapi2.instrument_adapter(kwargs["dbapi"], "sqlalchemy")
     return wrapped(*args, **kwargs)
 
 
