@@ -22,11 +22,9 @@ class ContrastSessionDictProxy(wrapt.ObjectProxy):
     """
 
     def __setitem__(self, key, value):
+        result = None
         try:
             result = self.__wrapped__.__setitem__(key, value)
-        except Exception:
-            result = None
-            raise
         finally:
             analyze_setitem(result, (self, key, value))
 
