@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import sys
 
@@ -29,7 +29,7 @@ def apply_call(class_name, orig_func, self, args, kwargs):
     try:
         result = orig_func(*args, **kwargs)
     finally:
-        location = "lxml.etree.{}.__call__".format(class_name)
+        location = f"lxml.etree.{class_name}.__call__"
         apply_assess(location, self, result, args, kwargs)
     return result
 
@@ -44,9 +44,9 @@ class ContrastXPathEvaluatorProxy(CallableObjectProxy):
     subclass and a proxied class that we return from the instrumented factory.
     """
 
-    def __call__(self, *args, **kwargs):
-        self_obj = self.__wrapped__
-        orig_func = self.__wrapped__.__call__
+    def __call__(__cs_self, *args, **kwargs):
+        self_obj = __cs_self.__wrapped__
+        orig_func = __cs_self.__wrapped__.__call__
         return apply_call(
             self_obj.__class__.__name__, orig_func, self_obj, args, kwargs
         )
@@ -62,10 +62,10 @@ def create_instrumented_xpath_element_evaluator(XPathElementEvaluator):
     """
 
     class ContrastXPathElementEvaluator(XPathElementEvaluator):
-        def __call__(self, *args, **kwargs):
-            orig_func = super(ContrastXPathElementEvaluator, self).__call__
+        def __call__(__cs_self, *args, **kwargs):
+            orig_func = super().__call__
             return apply_call(
-                XPathElementEvaluator.__name__, orig_func, self, args, kwargs
+                XPathElementEvaluator.__name__, orig_func, __cs_self, args, kwargs
             )
 
     return ContrastXPathElementEvaluator
@@ -79,10 +79,10 @@ def create_instrumented_xpath_document_evaluator(XPathDocumentEvaluator):
     """
 
     class ContrastXPathDocumentEvaluator(XPathDocumentEvaluator):
-        def __call__(self, *args, **kwargs):
-            orig_func = super(ContrastXPathDocumentEvaluator, self).__call__
+        def __call__(__cs_self, *args, **kwargs):
+            orig_func = super().__call__
             return apply_call(
-                XPathDocumentEvaluator.__name__, orig_func, self, args, kwargs
+                XPathDocumentEvaluator.__name__, orig_func, __cs_self, args, kwargs
             )
 
     return ContrastXPathDocumentEvaluator
@@ -98,11 +98,11 @@ def create_instrumented_xpath(XPath):
     """
 
     class ContrastXPath(XPath):
-        def __init__(self, *args, **kwargs):
+        def __init__(__cs_self, *args, **kwargs):
             try:
-                super(ContrastXPath, self).__init__(*args, **kwargs)
+                super().__init__(*args, **kwargs)
             finally:
-                apply_assess("lxml.etree.XPath.__init__", self, None, args, kwargs)
+                apply_assess("lxml.etree.XPath.__init__", __cs_self, None, args, kwargs)
 
     return ContrastXPath
 
