@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import sys
 
-from contrast.extern.six import PY2
-
 from contrast.extern.wrapt import register_post_import_hook
 from contrast.agent.policy import patch_manager
 from contrast.utils.patch_utils import build_and_apply_patch
@@ -23,9 +21,7 @@ def build_noop_patch(*_):
 
 
 def patch_sys(module):
-    if not PY2:
-        # sys.intern is PY3 only
-        build_and_apply_patch(module, "intern", build_noop_patch)
+    build_and_apply_patch(module, "intern", build_noop_patch)
 
 
 def register_patches():
