@@ -2,6 +2,12 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from quart import Response
+
+from contrast.agent.assess.rules.config import (
+    FlaskSessionAgeRule as QuartSessionAgeRule,
+    FlaskSecureFlagRule as QuartSecureFlagRule,
+    FlaskHttpOnlyRule as QuartHttpOnlyRule,
+)
 from contrast.agent.middlewares.route_coverage.common import (
     create_routes,
     build_route,
@@ -15,6 +21,12 @@ from contrast.utils.decorators import fail_safely
 class QuartMiddleware(ASGIMiddleware):
     def __init__(self, app):
         self.quart_app = app
+        self.config_rules = [
+            QuartSessionAgeRule(),
+            QuartSecureFlagRule(),
+            QuartHttpOnlyRule(),
+        ]
+
         super().__init__(app.asgi_app, app.name)
 
     def generate_security_exception_response(self):
@@ -34,3 +46,8 @@ class QuartMiddleware(ASGIMiddleware):
     @fail_safely("Unable to get Quart view func")
     def get_view_func(self, request):
         return get_view_func_for_request(request, self.quart_app)
+
+    @fail_safely("Failed to run config scanning rules")
+    def scan_configs(self):
+        for rule in self.config_rules:
+            rule.apply(self.quart_app)
