@@ -9,11 +9,12 @@ from contrast.agent import scope
 from contrast.agent.settings import Settings
 from contrast.reporting import RequestAudit
 from contrast.extern import structlog as logging
+from contrast.utils.singleton import Singleton
 
 logger = logging.getLogger("contrast")
 
 
-class ReportingClient(threading.Thread):
+class ReportingClient(Singleton, threading.Thread):
     def __init__(self):
         self.message_q = queue.Queue(maxsize=128)
         self.settings = Settings()
@@ -39,14 +40,17 @@ class ReportingClient(threading.Thread):
                 try:
                     msg = self.message_q.get(block=True, timeout=5)
                     response = self.send_message(msg)
-                    msg.process_response(response)
+                    msg.process_response(response, self)
                 except queue.Empty:
                     pass
 
     def send_message(self, msg):
+        msg_name = type(msg).__name__
         try:
             logger.debug(
-                "Sending message to Teamserver %s", type(msg), direct_to_teamserver=1
+                "Sending %s message to Teamserver",
+                msg_name,
+                direct_to_teamserver=1,
             )
 
             cert = None
@@ -81,7 +85,12 @@ class ReportingClient(threading.Thread):
                 cert=cert,
             )
 
-            logger.debug("Teamserver response: %s", response, direct_to_teamserver=1)
+            logger.debug(
+                "Teamserver response (%s): %s",
+                msg_name,
+                response.status_code,
+                direct_to_teamserver=1,
+            )
 
             if self.request_audit:
                 self.request_audit.audit(msg, response)
@@ -90,7 +99,8 @@ class ReportingClient(threading.Thread):
 
         except Exception as e:
             logger.exception(
-                "Failed to send message to Contrast: %s",
+                "Failed to send %s message to Contrast: %s",
+                msg_name,
                 e,
                 direct_to_teamserver=1,
             )
@@ -103,7 +113,9 @@ class ReportingClient(threading.Thread):
             return
 
         logger.debug(
-            "Adding msg to reporting queue: %s", type(msg), direct_to_teamserver=1
+            "Adding msg to reporting queue: %s",
+            type(msg).__name__,
+            direct_to_teamserver=1,
         )
 
         self.message_q.put(msg)
