@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from __future__ import print_function
 
@@ -37,7 +37,7 @@ def _check_filetype():
     This check is not particularly robust, but it's about as good as we
     can do without significantly more effort (or a new dependency).
     """
-    print("found interpreter: {}".format(INTERPRETER))
+    print(f"found interpreter: {INTERPRETER}")
     print("verifying interpreter filetype - expecting Mach-O")
     file_info = subprocess.check_output(["file", INTERPRETER]).decode().rstrip()
     print(file_info)
@@ -78,13 +78,13 @@ Exiting - no modifications performed.
 
 def _run():
     print("found --modify-interpreter command line option")
-    print("the following interpreter will be modified:\n{}\n".format(INTERPRETER))
+    print(f"the following interpreter will be modified:\n{INTERPRETER}\n")
 
     byte_7 = subprocess.Popen(["echo", "-n", "\x07"], stdout=subprocess.PIPE)
     subprocess.check_call(
         [
             "dd",
-            "of={}".format(INTERPRETER),
+            f"of={INTERPRETER}",
             "bs=1",
             "seek=160",
             "count=1",
