@@ -93,7 +93,7 @@ def _load_config(file_path):
 
     with open(file_path, "r") as config_file:
         try:
-            return yaml.safe_load(config_file)
+            return yaml.YAML(typ="safe", pure=True).load(config_file)
         except yaml.scanner.ScannerError as ex:
             # config yaml cannot be loaded but agent should continue on in case
             # env vars are configured
