@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from io import open
 import ast
-from contrast.extern import six
 
 
 def get_ast_parsed_code(path):
@@ -17,7 +16,7 @@ def get_ast_parsed_code(path):
     with open(path, encoding="utf-8") as path_file:
         text = path_file.read()
 
-    if isinstance(text, six.string_types):
+    if isinstance(text, str):
         code_text = text.encode("utf-8", "ignore")
     else:
         code_text = str(text)
