@@ -10,9 +10,9 @@ class Profiler(cProfile.Profile):
     def __init__(self, path):
         super().__init__()
 
-        from contrast.agent.settings_state import SettingsState
+        from contrast.agent.settings import Settings
 
-        self.settings = SettingsState()
+        self.settings = Settings()
         self.path = path
 
     def __enter__(self):
