@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+import pathlib
 import platform
 import psutil
 import time
@@ -18,8 +19,6 @@ def make_sure_path_exists(log_path):
     if directory in ("", "/"):
         return
 
-    from contrast import pathlib
-
     pathlib.Path(directory).mkdir(parents=True, exist_ok=True)
 
 
