@@ -7,7 +7,6 @@ import contrast
 from contrast.agent.policy.trigger_node import TriggerNode
 from contrast.agent.middlewares.base_middleware import BaseMiddleware
 from contrast.agent.middlewares.environ_tracker import track_environ_sources
-from contrast.agent.request_context import RequestContext
 from contrast.utils.decorators import cached_property, fail_safely, log_time_cm
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.exceptions.contrast_service_exception import (
@@ -39,21 +38,18 @@ class WSGIMiddleware(BaseMiddleware):
         self.wsgi_app = wsgi_app
 
     def __call__(self, environ, start_response):
-        self.orig_path_info = environ.get("PATH_INFO")
+        self.request_path = environ.get("PATH_INFO", "")
 
-        with Profiler(self.orig_path_info):
-            if self.is_agent_enabled():
-                if self.settings.ignore_request(self.orig_path_info):
-                    return self.call_without_agent(environ, start_response)
-
-                context = RequestContext(environ)
+        with Profiler(self.request_path):
+            context = self.should_analyze_request(environ)
+            if context:
                 with contrast.CS__CONTEXT_TRACKER.lifespan(context):
                     return self.call_with_agent(context, environ, start_response)
 
             return self.call_without_agent(environ, start_response)
 
     def call_with_agent(self, context, environ, start_response):
-        self.log_start_request_analysis(environ.get("PATH_INFO"))
+        self.log_start_request_analysis()
 
         track_environ_sources("wsgi", context, environ)
 
@@ -85,7 +81,7 @@ class WSGIMiddleware(BaseMiddleware):
             response = self.handle_exception(e)
             return response(environ, start_response)
         finally:
-            self.log_end_request_analysis(context.request.path)
+            self.log_end_request_analysis()
             if self.settings.is_assess_enabled():
                 contrast.STRING_TRACKER.ageoff()
 
@@ -108,7 +104,7 @@ class WSGIMiddleware(BaseMiddleware):
         As a workaround, we store the original PATH_INFO - before bottle changed it
         during calling app code - and use it for agent purposes.
         """
-        environ["PATH_INFO"] = self.orig_path_info
+        environ["PATH_INFO"] = self.request_path
 
     def generate_security_exception_response(self):
         return Response(self.OVERRIDE_MESSAGE, SecurityException.STATUS)
@@ -117,7 +113,7 @@ class WSGIMiddleware(BaseMiddleware):
         """
         Normal without middleware call
         """
-        super().call_without_agent(self.orig_path_info)
+        super().call_without_agent()
         return self.wsgi_app(environ, start_response)
 
     def get_route_coverage(self):
@@ -150,7 +146,7 @@ class WSGIMiddleware(BaseMiddleware):
         )
 
     @fail_safely("Unable to get WSGI view func")
-    def get_view_func(self, request):
+    def get_view_func(self, _):
         """
         While most frameworks define view functions, WSGI doesn't so we will rely
         on the path information for reporting.
@@ -159,7 +155,7 @@ class WSGIMiddleware(BaseMiddleware):
         :param request: RequestContext instance
         :return: string of path information for this request
         """
-        return request.environ.get("PATH_INFO", "")
+        return self.request_path or None
 
     @fail_safely("Unable to build route", return_value="")
     def build_route(self, view_func, url):
